@@ -117,84 +117,6 @@ nse_format_num <- function(data, cols_skip, cols_modify) {
 
 }
 
-#' Read data from Yahoo Finance API
-#'
-#' @param url URL of the stock.
-#'
-#' @noRd
-#'
-nse_stock_quote_data <- function(url) {
-  url %>%
-    jsonlite::read_json() %>%
-    magrittr::use_series(chart) %>%
-    magrittr::use_series(result) %>%
-    magrittr::extract2(1) %>%
-    magrittr::use_series(meta) %>%
-    magrittr::use_series(regularMarketPrice)
-}
-
-#' Download stock quote from Rediff Money
-#'
-#' @param stock_code Stock code.
-#'
-#' @noRd
-#'
-nse_stock_quote_rediff <- function(stock_code) {
-
-  url <- "https://www1.nseindia.com/content/equities/EQUITY_L.csv"
-
-  url %>%
-    utils::read.csv() %>%
-    magrittr::extract(., c(1, 7)) %>%
-    lapply(as.character) %>%
-    as.data.frame() -> result
-
-  colnames(result) <- c("symbol", "isin")
-
-  isin      <- result[result$symbol == toupper(stock_code), ]$isin
-  base_url  <- "https://money.rediff.com/companies/"
-  stock_url <- paste0(base_url, isin)
-  read_url  <- xml2::read_html(stock_url)
-
-  read_url %>%
-    rvest::html_nodes(xpath = '//span[@id="ltpid_nse"]') %>%
-    rvest::html_text() %>%
-    as.numeric()
-
-}
-
-#' Download stock quote from Rediff Money
-#'
-#' @param stock_code Stock code.
-#'
-#' @noRd
-#'
-nse_stock_quote_yahoo <- function(stock_code) {
-
-  base_url <- "https://query1.finance.yahoo.com/v8/finance/chart/"
-  alt_url  <- "https://query2.finance.yahoo.com/v8/finance/chart/"
-
-  # check output from primary url
-  url        <- paste0(base_url, toupper(stock_code), ".NS")
-  url_resp   <- GET(url)
-  url_status <- http_status(url_resp)
-
-  # check output from backup url
-  url2        <- paste0(alt_url, toupper(stock_code), ".NS")
-  url2_resp   <- GET(url2)
-  url2_status <- http_status(url2_resp)
-
-  if (url_status$category == "Success") {
-    nse_stock_quote_data(url)
-  } else if (url2_status$category == "Success") {
-    nse_stock_quote_data(url2)
-  } else {
-    stop("No data available.", .call = FALSE)
-  }
-
-}
-
-
 #' @importFrom utils packageVersion menu install.packages
 check_suggests <- function(pkg) {
 
